<?php

declare(strict_types=1);

namespace Drupal\workspace_approval\Controller;

use Drupal\Core\Entity\Controller\EntityController;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Overrides the default entity controller to customize the add page.
 */
final class WorkspaceApprovalRequestController extends EntityController {

  /**
   * {@inheritdoc}
   */
  public function addBundleTitle(RouteMatchInterface $route_match, $entity_type_id, $bundle_parameter): string {
    $bundles = $this->entityTypeBundleInfo->getBundleInfo($entity_type_id);
    $bundle = $route_match->getRawParameter($bundle_parameter);
    return (string) $this->t('Request @bundle', ['@bundle' => \strtolower($bundles[$bundle]['label'])]);
  }

  /**
   * {@inheritdoc}
   */
  public function addPage($entity_type_id): RedirectResponse|array {
    $build = parent::addPage($entity_type_id);
    if (!\is_array($build)) {
      return $build;
    }
    foreach ($build['#bundles'] ?? [] as $bundle => &$option) {
      $form_route_name = 'entity.' . $entity_type_id . '.add_form';
      $bundle_parameter = $this->entityTypeManager->getDefinition($entity_type_id)?->getBundleEntityType();
      $parameters = $this->routeMatch->getRawParameters()->all();
      $parameters[$bundle_parameter] = $bundle;
      $option['add_link']->setUrl(Url::fromRoute(
        $form_route_name,
        $parameters,
      ));
    }
    return $build;
  }

}
