<?php

declare(strict_types=1);

namespace Drupal\workspace_approval\EventSubscriber;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Queue\QueueFactory;
use Drupal\entity_workflow\Event\PostTransitionEvent;
use Drupal\workspace_approval\Plugin\QueueWorker\ReviewerNotificationQueueWorker;
use Drupal\workspace_approval\WorkspaceApprovalRequestInterface;
use Drupal\workspace_approval\WorkspaceApprovalRequestStorageInterface;
use Drupal\workspaces\WorkspaceInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Subscribes to workflow transition events.
 */
final class WorkspaceApprovalNotifyEventSubscriber implements EventSubscriberInterface {

  /**
   * Builds a new WorkspaceApprovalNotifyEventSubscriber object.
   */
  public function __construct(
    private readonly EntityTypeManagerInterface $entityTypeManager,
    private readonly QueueFactory $queueFactory,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      PostTransitionEvent::class => ['onPostTransition', 0],
    ];
  }

  /**
   * Queues notifications after a workflow has been transitioned.
   */
  public function onPostTransition(PostTransitionEvent $event): void {
    $workspace = $event->getEntity();
    if (!$workspace instanceof WorkspaceInterface) {
      return;
    }
    $storage = $this->entityTypeManager->getStorage('workspace_approval_request');
    \assert($storage instanceof WorkspaceApprovalRequestStorageInterface);
    // Get all requests that guard transitions for entity transitioned during
    // this event.
    $requests = $storage->getApprovalRequests(NULL, (string) $workspace->id());
    foreach ($requests as $request) {
      \assert($request instanceof WorkspaceApprovalRequestInterface);
      if (!$request->isApproved() && $request->isApprovalRequired($event->getWorkflow())) {
        $data = ReviewerNotificationQueueWorker::createData($request);
        $this->queueFactory->get(ReviewerNotificationQueueWorker::ID)->createItem($data);
      }
    }
  }

}
