<?php

declare(strict_types=1);

namespace Drupal\workspace_approval\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\workspace_approval\WorkspaceApprovalRequestInterface;

/**
 * Provides a confirmation form to approve an approval request.
 */
final class WorkspaceApprovalRequestApproveForm extends WorkspaceApprovalRequestConfirmForm {

  /**
   * {@inheritdoc}
   */
  protected $operation = 'approve';

  /**
   * {@inheritdoc}
   */
  public function getQuestion(): TranslatableMarkup {
    return $this->t('Approve this %title?', [
      '%title' => $this->getBundleEntity()?->label(),
    ]);
  }

  /**
   * {@inheritdoc}
   */
  public function getDescription(): TranslatableMarkup {
    return $this->t("This action will allow this content to transition to its next workflow state.");
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl(): Url {
    return Url::fromUserInput($this->getRedirectDestination()->get())->setAbsolute();
  }

  /**
   * {@inheritdoc}
   */
  protected function entityPreSave(WorkspaceApprovalRequestInterface $entity, array &$form, FormStateInterface $form_state): void {
    $entity->set('approved', TRUE);
  }

  /**
   * {@inheritdoc}
   */
  protected function entityPostSave(WorkspaceApprovalRequestInterface $entity, array &$form, FormStateInterface $form_state): void {
    $form_state->setRedirectUrl(Url::fromRoute(
      'entity.workspace_approval_request.list.workspace',
      ['workspace' => $entity->getSubject()->id()],
    ));
  }

}
