<?php

declare(strict_types=1);

namespace Drupal\workspace_approval\Plugin\QueueWorker;

use Drupal\Core\Queue\Attribute\QueueWorker;
use Drupal\Core\Queue\QueueWorkerManagerInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\workspace_approval\WorkspaceApprovalNotifications;
use Drupal\workspace_approval\WorkspaceApprovalRequestInterface;

/**
 * Process a queue of workspace transitions to send notifications.
 */
#[QueueWorker(
  id: self::ID,
  title: new TranslatableMarkup('Requester notification queue'),
  cron: ['time' => QueueWorkerManagerInterface::DEFAULT_QUEUE_CRON_TIME],
)]
final class RequesterNotificationQueueWorker extends NotificationQueueWorkerBase {

  /**
   * The queue name processed by this worker.
   */
  public const string ID = 'workspace_approval_requester_notification_queue';

  /**
   * {@inheritdoc}
   */
  protected ?WorkspaceApprovalNotifications $notificationType = WorkspaceApprovalNotifications::ReviewProvided;

  /**
   * {@inheritdoc}
   */
  protected function getUidToNotify(WorkspaceApprovalRequestInterface $workspace_approval_request): ?int {
    return (int) $workspace_approval_request->getOwnerId();
  }

}
