<?php

declare(strict_types=1);

namespace Drupal\workspace_approval\Plugin\QueueWorker;

use Drupal\Core\Queue\Attribute\QueueWorker;
use Drupal\Core\Queue\QueueWorkerManagerInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\workspace_approval\WorkspaceApprovalNotifications;
use Drupal\workspace_approval\WorkspaceApprovalRequestInterface;

/**
 * Process a queue of workspace transitions to send notifications.
 */
#[QueueWorker(
  id: self::ID,
  title: new TranslatableMarkup('Reviewer notification queue'),
  cron: ['time' => QueueWorkerManagerInterface::DEFAULT_QUEUE_CRON_TIME],
)]
final class ReviewerNotificationQueueWorker extends NotificationQueueWorkerBase {

  /**
   * The queue name processed by this worker.
   */
  public const string ID = 'workspace_approval_reviewer_notification_queue';

  /**
   * {@inheritdoc}
   */
  protected ?WorkspaceApprovalNotifications $notificationType = WorkspaceApprovalNotifications::ReviewRequested;

  /**
   * {@inheritdoc}
   */
  protected function getUidToNotify(WorkspaceApprovalRequestInterface $workspace_approval_request): ?int {
    $reviewer = $workspace_approval_request->getReviewer();
    return \is_null($reviewer)
      ? NULL
      : (int) $reviewer->id();
  }

}
