<?php

declare(strict_types=1);

namespace Drupal\workspace_approval;

use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\entity\BundleFieldDefinition;

/**
 * A field definition for a field that stores a workspace approval request.
 */
final class WorkspaceApprovalRequestField extends BundleFieldDefinition {

  /**
   * The field name for the field storing a workspace approval request.
   */
  public const string FIELD_NAME = 'workspace_approval_request';

  /**
   * Creates a new WorkspaceApprovalRequestFieldDefinition object.
   */
  public static function createDefinition(string $fieldName, EntityTypeInterface $entityType, ?string $bundle = NULL): self {
    $definition = parent::create('entity_reference')
      ->setName($fieldName)
      ->setTargetEntityTypeId($entityType->id())
      ->setDisplayConfigurable('form', FALSE)
      ->setDisplayConfigurable('view', FALSE)
      ->setRevisionable(FALSE)
      ->setTranslatable(FALSE)
      ->setLabel(new TranslatableMarkup('Workspace approval request'))
      ->setDescription(new TranslatableMarkup('A workspace approval request'))
      ->setSettings(['target_type' => 'workspace_approval_request']);
    return \is_string($bundle)
      ? $definition->setTargetBundle($bundle)
      : $definition;
  }

}
