<?php

declare(strict_types=1);

namespace Drupal\workspace_approval;

use Drupal\Core\Entity\Query\QueryInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Provides a list of current user's outstanding workspace approval requests.
 */
final class WorkspaceApprovalRequestReviewerListBuilder extends WorkspaceApprovalRequestListBuilderBase implements WorkspaceApprovalRequestReviewerListBuilderInterface {

  /**
   * The user for whom the listing will be built.
   *
   * @var \Drupal\Core\Session\AccountInterface|null
   *   The user's account object.
   */
  private ?AccountInterface $reviewer = NULL;

  /**
   * {@inheritdoc}
   */
  public function getTitle(): TranslatableMarkup|string {
    return $this->t('My approval requests');
  }

  /**
   * {@inheritdoc}
   */
  public function setReviewer(AccountInterface $reviewer): void {
    $this->reviewer = $reviewer;
  }

  /**
   * {@inheritdoc}
   */
  protected function getEntityListQuery(): QueryInterface {
    if (\is_null($this->reviewer)) {
      throw new \LogicException(self::class . '::setReviewer() must be called before ::getEntityListQuery()');
    }
    $query = parent::getEntityListQuery();
    $query->condition('reviewer', $this->reviewer->id());
    return $query;
  }

  /**
   * {@inheritdoc}
   */
  public function render(): array {
    $build = parent::render();

    $build['table']['#empty'] = $this->t('You do not have any pending review requests at this time.');

    return $build;
  }

}
