<?php

declare(strict_types=1);

namespace Drupal\workspace_approval;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Url;

/**
 * Defines a class to list workspace approval request type entities.
 *
 * @see \Drupal\workspace_approval\Entity\WorkspaceApprovalRequestType
 */
final class WorkspaceApprovalRequestTypeListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader(): array {
    $header = [];
    $header['label'] = $this->t('Label');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity): array {
    $row = [];
    $row['label'] = $entity->label();
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function render(): array {
    $build = parent::render();

    $build['table']['#empty'] = $this->t(
      'No workspace approval request types available. <a href=":link">Add workspace approval request type</a>.',
      [':link' => Url::fromRoute('entity.workspace_approval_request_type.add_form')->toString()],
    );

    return $build;
  }

}
