<?php

/**
 * @file
 * Post-update hooks for the Workspace approval module.
 */

declare(strict_types=1);

use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Drupal\Core\Config\Entity\ConfigEntityStorageInterface;

/**
 * Delete orphaned requests pre-dating workspace_approval_ENTITY_TYPE_delete()s.
 */
function workspace_approval_post_update_clean_up_orphaned_requests(array &$sandbox): void {
  $requestStorage = \Drupal::entityTypeManager()->getStorage('workspace_approval_request');
  $userStorage = \Drupal::entityTypeManager()->getStorage('user');
  $workspaceStorage = \Drupal::entityTypeManager()->getStorage('workspace');
  $orphanQuery = $requestStorage->getQuery()->accessCheck(FALSE);
  $subjectOrUserMissing = $orphanQuery->orConditionGroup()
    ->condition('subject', $workspaceStorage->getQuery()->accessCheck(FALSE), 'NOT IN')
    ->condition('reviewer', $userStorage->getQuery()->accessCheck(FALSE), 'NOT IN');
  $orphans = $orphanQuery->condition($subjectOrUserMissing)->execute();
  $requestsToDelete = $requestStorage->loadMultiple($orphans);
  foreach ($requestsToDelete as $request) {
    $request->delete();
  }
}

/**
 * Migrate the "transition" config property to "guarded_transition".
 */
function workspace_approval_post_update_workspace_approval_request_types(array &$sandbox): void {
  $requestTypeStorage = \Drupal::entityTypeManager()->getStorage('workspace_approval_request_type');
  \assert($requestTypeStorage instanceof ConfigEntityStorageInterface);
  foreach ($requestTypeStorage->loadMultiple() as $requestType) {
    \assert($requestType instanceof ConfigEntityInterface);
    $transition = $requestType->get('transition');
    $requestType->set('guarded_transitions', [$transition]);
    $requestType->save();
  }
}
